@@ -31,6 +31,7 @@
 #include <fcntl.h>
 #include <pwd.h>
 #include <libintl.h>
+#include <locale.h>
 
 #include <dbus/dbus.h>
 #include <libhal.h>
@@ -42,7 +43,7 @@
 #define LOCKFILENAME "/" PACKAGE ".lock"
 #define DEVICEFILENAME "/uditab"
 #define TMPPOSTFIX ".tmp"
-#define MASKOPTSTR "umask="
+#define UMASKOPTSTR "umask="
 #define UIDOPTSTR "uid="
 
 typedef struct halevt_mount_udi
@@ -533,7 +534,7 @@ halevt_mount_udi **halevt_mount_find_udi (const char *udi, const char *device,
   return list;
 }
 
-void halevt_mount_umount (DBusConnection *dbus_connection, halevt_mount_udi *udi)
+int halevt_mount_umount (DBusConnection *dbus_connection, halevt_mount_udi *udi)
 {
   DBusError dbus_error;
   DBusMessage *dbus_msg;
@@ -544,14 +545,14 @@ void halevt_mount_umount (DBusConnection *dbus_connection, halevt_mount_udi *udi
        "org.freedesktop.Hal.Device.Volume", "Unmount")) == NULL)
   {
     fprintf (stderr, "Out of memory\n");
-    return;
+    return 0;
   }
   if (! (dbus_message_append_args (dbus_msg, 
        DBUS_TYPE_ARRAY, DBUS_TYPE_STRING, &options_array, 0, 
        DBUS_TYPE_INVALID)))
   {
     fprintf (stderr, _("Out of memory\n"));
-    return;
+    return 0;
   }
     
   dbus_error_init (&dbus_error);
@@ -559,8 +560,11 @@ void halevt_mount_umount (DBusConnection *dbus_connection, halevt_mount_udi *udi
       (dbus_connection, dbus_msg, -1, &dbus_error)) == NULL) || dbus_error_is_set (&dbus_error))
   {
     fprintf (stderr, _("Unmount error for %s:\n"), udi->udi);
+    halevt_mount_check_dbus_error (&dbus_error);
+    return 0;
   }
   halevt_mount_check_dbus_error (&dbus_error);
+  return 1;
 }
 
 halevt_mount_udi *halevt_mount_new_udi (char *udi)
@@ -713,15 +717,15 @@ void usage()
 ); 
 }
 
-int halevt_mount_add_option(char **options_array, char * option, int option_nr)
+int halevt_mount_add_option(char ***options_array, char * option, int option_nr)
 {
   option_nr++;
-  if ((realloc (options_array, option_nr * sizeof(char *))) == NULL)
+  if ((*options_array = realloc (*options_array, option_nr * sizeof(char *))) == NULL)
   {
     fprintf (stderr, _("Out of memory\n"));
     return 0;
   }
-  if ((options_array[option_nr - 1] = strdup(option)) == NULL)
+  if (((*options_array)[option_nr - 1] = strdup(option)) == NULL)
   {
     fprintf (stderr, _("Out of memory\n"));
     return 0;
@@ -739,6 +743,7 @@ int main (int argc, char **argv)
   int fd_lock;
   int c;
   int do_all = 0;
+  int set_umask = 0;
   char *device_file = NULL;
   char *tmp_device_file;
   char *device = NULL;
@@ -837,22 +842,20 @@ int main (int argc, char **argv)
          }
          break;
        case 'o':
-         option_nr = halevt_mount_add_option(options_array, optarg, option_nr);
+         option_nr = halevt_mount_add_option(& options_array, optarg, option_nr);
          if (option_nr == 0) { exit (1); }
          break;
        case 'm':
          if (system_user)
          {
-           if ((mask_string = (char *) malloc ((1 + strlen (optarg) + strlen (MASKOPTSTR)) * sizeof(char))) == NULL)
+           if ((mask_string = (char *) malloc ((1 + strlen (optarg) + strlen (UMASKOPTSTR)) * sizeof(char))) == NULL)
            {
              fprintf (stderr, _("Out of memory\n"));
              exit (1);
            }
-           strcpy (mask_string, MASKOPTSTR);
+           strcpy (mask_string, UMASKOPTSTR);
            strcat (mask_string, optarg);
-           option_nr = halevt_mount_add_option(options_array, mask_string, option_nr);
-           if (option_nr == 0) { exit (1); }
-           free (mask_string);
+           set_umask = 1;
          }
          break;
        case 'a':
@@ -1104,7 +1107,17 @@ int main (int argc, char **argv)
 
     if (mountpoint == NULL) { mountpoint = ""; }
 
-    if (! system_user && halevt_mount_check_mount_option(new_device_udi, hal_ctx, "uid="))
+    if (set_umask)
+    {
+       if (halevt_mount_check_mount_option(new_device_udi, hal_ctx, UMASKOPTSTR))
+       {
+          option_nr = halevt_mount_add_option(& options_array, mask_string, option_nr);
+          if (option_nr == 0) { exit (1); }
+       }
+       free (mask_string);
+    }
+
+    if (! system_user && halevt_mount_check_mount_option(new_device_udi, hal_ctx, UIDOPTSTR))
     {
        snprintf(uid_nr, 49, "%d", getuid());
        uid_nr[49] = '\0';
@@ -1116,7 +1129,7 @@ int main (int argc, char **argv)
        strcpy (uid_string, UIDOPTSTR);
        strcat (uid_string, uid_nr);
        
-       option_nr = halevt_mount_add_option(options_array, uid_string, option_nr);
+       option_nr = halevt_mount_add_option(& options_array, uid_string, option_nr);
        if (option_nr == 0) { exit (1); }
        free (uid_string);
     }
@@ -1170,12 +1183,14 @@ int main (int argc, char **argv)
       {
         if (! strcmp (cmd, "umount"))
         {
+          int unmount_done = 0;
           current_udi_found = udi_found;
           while ((*current_udi_found) != NULL)
           {
-            halevt_mount_umount (dbus_connection, *current_udi_found);
+            if (halevt_mount_umount (dbus_connection, *current_udi_found)) { unmount_done = 1; }
             current_udi_found++;
           }
+          if (!unmount_done) { exit (1); }
         }
         else if (! strcmp (cmd, "clean"))
         { /* remove the udi, device or mountpoints from the list */
@@ -1206,7 +1221,19 @@ int main (int argc, char **argv)
           }
         }
       }
-    /*  else { fprintf (stderr, "Nothing found to be processed\n"); } */
+      else 
+      {
+        if (! strcmp (cmd, "list"))
+        {  
+          fprintf (stderr, _("Cannot find a device to be listed\n"));
+          exit (1);
+        }
+        else
+        {
+          fprintf (stderr, _("Cannot find a device to be umounted\n"));
+          exit (1);
+        }
+      }
     }
     /* when umounting we don't write to the device file, to avoid messing
      with file permissions in case the umount was done as root */
