@@ -248,7 +248,7 @@ halevt_boolean_expression *halevt_new_boolean_expression(char *original_string)
       {
           DEBUG(_("Runaway parenthesis in boolean expression \"%s\""), new_expression->string);
       }
-      else if (bool_error == BOOLSTUFF_ERR_STRING_EXPECTED)
+      else if (bool_error == BOOLSTUFF_ERR_IDENTIFIER_EXPECTED)
       {
           DEBUG(_("String instead of operator expected in boolean expression \"%s\""), new_expression->string);
       }
